# coding: utf8
from __future__ import unicode_literals


PRONOUNS_IRREG = {
    "aucune": ("aucun",),
    "celle-ci": ("celui-ci",),
    "celles-ci": ("celui-ci",),
    "ceux-ci": ("celui-ci",),
    "celle-là": ("celui-là",),
    "celles-là": ("celui-là",),
    "ceux-là": ("celui-là",),
    "celle": ("celui",),
    "celles": ("celui",),
    "ceux": ("celui",),
    "certaines": ("certains",),
    "chacune": ("chacun",),
    "icelle": ("icelui",),
    "icelles": ("icelui",),
    "iceux": ("icelui",),
    "la": ("le",),
    "les": ("le",),
    "laquelle": ("lequel",),
    "lesquelles": ("lequel",),
    "lesquels": ("lequel",),
    "elle-même": ("lui-même",),
    "elles-mêmes": ("lui-même",),
    "eux-mêmes": ("lui-même",),
    "quelle": ("quel",),
    "quelles": ("quel",),
    "quels": ("quel",),
    "quelques-unes": ("quelqu'un",),
    "quelques-uns": ("quelqu'un",),
    "quelque-une": ("quelqu'un",),
    "qu": ("que",),
    "telle": ("tel",),
    "telles": ("tel",),
    "tels": ("tel",),
    "toutes": ("tous",),
}